Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(281)

Unified Diff: net/tools/testserver/testserver.py

Issue 2137193002: Update token binding code to latest drafts (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Remove unnecessary cast Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/ssl/token_binding.cc ('k') | net/url_request/url_request_job.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/tools/testserver/testserver.py
diff --git a/net/tools/testserver/testserver.py b/net/tools/testserver/testserver.py
index ba130af9943364d9941f55cba3746f2175a799dc..7950f351baa63189dd032d03582875bacf053bba 100755
--- a/net/tools/testserver/testserver.py
+++ b/net/tools/testserver/testserver.py
@@ -1534,7 +1534,7 @@ class TestPageHandler(testserver_base.BasePageHandler):
return True
def ForwardTokenBindingHeader(self):
"""Send a redirect that sets the Include-Referer-Token-Binding-ID
header."""
test_name = '/forward-tokbind'
@@ -1549,7 +1549,7 @@ class TestPageHandler(testserver_base.BasePageHandler):
self.send_response(302)
self.send_header('Location', dest)
- self.send_header('Include-Referer-Token-Binding-ID', 'true')
+ self.send_header('Include-Referred-Token-Binding-ID', 'true')
self.end_headers()
return True
« no previous file with comments | « net/ssl/token_binding.cc ('k') | net/url_request/url_request_job.cc » ('j') | no next file with comments »
@@ -1534,7 +1534,7 @@ class TestPageHandler(testserver_base.BasePageHandler):
return True
def ForwardTokenBindingHeader(self):
- """Send a redirect that sets the Include-Referer-Token-Binding-ID
+ """Send a redirect that sets the Include-Referred-Token-Binding-ID
header."""
test_name = '/forward-tokbind'

Powered by Google App Engine
This is Rietveld 408576698